@@ -241,10 +241,11 @@ resolve_sockaddr(gchar *result, gsize *result_len, GSockAddr *saddr, gboolean us
     {
       gint i;
 
-      for (i = 0; hname[i] && i < (*result_len); i++)
+      for (i = 0; hname[i] && i < ((*result_len) - 1); i++)
         {
           result[i] = g_ascii_tolower(hname[i]);
         }
+      result[i] = '\0'; /* the closing \0 is not copied by the previous loop */
       *result_len = i;
     }
   else
@@ -399,7 +400,7 @@ create_containing_directory(gchar *name, gint dir_uid, gint dir_gid, gint dir_mo
         }
       else if (errno == ENOENT) 
         {
-          if (mkdir(name, (mode_t) dir_mode) == -1)
+          if (mkdir(name, dir_mode < 0 ? 0700 : (mode_t) dir_mode) == -1)
             return FALSE;
           if (dir_uid >= 0)
             chown(name, (uid_t) dir_uid, -1);
